# proginoskes
Monitor your infastructure in real time

## install ##
To install `npm install proginoskes`

## configuration ##
The available configuration sections and options.

1. _global_: Anything defined here is applied to all defined hosts
  1. _server_: A server name defined here will work as a defined host
  2. _port_: The default is 22 and is applied to all hosts unless explicitly defined
  3. _username_: A username defined here will apply to all hosts
  4. _password_: A password defined here will also apply to all hosts
  5. _privateKey_: The path to a private ssh key (also applies to all defined hosts)
  6. _logs_: An array of logs to monitor for all defined hosts
  7. _ignore_: An array of filtering options
    1. _destination_: An array of destination string(s) to ignore
    2. _source_: An array of source string(s) to ignore
    3. _ports_: An array of TCP/UDP port(s) to ignore
2. _hosts_: The recommended method of including `server` definitions
  1. _server_: The name or IP of machine to apply log monitoring streams
  2. _port_: The SSH port for this particular host, uses global `port` option if omitted
  3. _username_: The username for access, also uses the global `username` option if omitted
  4. _password_: The password for access, again, uses the global `password` option if omitted
  5. _privateKey_: The path to an SSH private key to use with this host. Will also use anything defined in global `privateKey` if omitted
  6. _logs_: An array of logs to monitor for this host. Adds to anything defined in global `logs` array
  7. _ignore_: An array of filtering options (per host)
    1. _destination_: An array of destination string(s) to ignore. Adds to anything defined in global `ignore` -> `destination` option
    2. _source_: An array of source string(s) to ignore. Adds to anything defined in global `ignore` -> `source` option
    3. _ports_: An array of TCP/UDP port(s) to ignore. Adds to anything defined in global `ports` -> `destination` option

Two sections; `global` & `hosts`. Anything in global may be overwritten by a
defined host while the `logs` and `ignore` sections will apply to all defined
hosts.

_Example_
```javascript
var options = {
  global: {
    port: 22,
    username: 'root',
    privateKey: './path/to/global/privatekey',
    logs: [
      '/var/log/ufw.log'
    ],
    ignore: {
      destination: [
        'localhost',
        '127.0.0.1'
      ],
      source: [
        'localhost',
        '127.0.0.1'
      ],
      ports: [
        53
      ]
    }
  },
  hosts: [
    {
      server: 'server-1.example',
      privateKey: './path/to/server-1.example/privatekey',
      logs: [
        '/var/log/snort/snort.log'
      ]
    },
    {
      server: 'server-2.example',
      port: 2222,
      username: 'iamroot',
      privateKey: './path/to/server-2.example/privatekey',
    },
    {
      server: 'server-3.example',
      password: 'secret-sauce',
      logs: [
        '/var/log/iptables.log'
      ]
    }
  ]
};
```

## usage ##
Once you have a good configuration with at least one defined host to monitor
usage is easy.

_Example_
```javascript
var cherubum = require('proginoskes');

cherubum.proginoskes(options, function(err, data) {
  if (err) throw err;

  console.log(data);
});
```

## returned object ##
The returned object(s) are simple, but makes it easy to determine source.

_Example_
```javascript```
{ server: 'localhost',
  log: ' /var/log/ufw.log',
  data: 'Jan  5 04:34:19 node kernel: DROP IN=eth0 OUT= MAC=52:54:00:12:34:56:52:55:0a:00:02:02:08:00 SRC=192.168.2.3 DST=10.0.2.15 LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=31709 PROTO=TCP SPT=38280 DPT=443 WINDOW=8760 RES=0x00 SYN URGP=0' },
{ server: 'localhost',
  log: ' /var/log/audit/audit.log',
  data: 'type=SYSCALL msg=audit(1420457768.368:2502): arch=c000003e syscall=54 success=yes exit=0 a0=3 a1=0 a2=40 a3=2033ca0 items=0 ppid=1298 pid=4565 auid=500 uid=0 gid=0 euid=0 suid=0 fsuid=0 egid=0 sgid=0 fsgid=0 tty=pts1 ses=5 comm="iptables" exe="/sbin/iptables-multi-1.4.7" subj=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023 key=(null)' },
```
